<!-- Default start messages -->
# **lynxy**
Local (yielding?) Network (eXchange?) (the extra y is cosmetic~)

# **Introduction**
lynxy, also known as lynx, is a LAN server-client system coded in Python. It allows for easy setup of a server, as well as easy setup for clients on the same network as the server.
The use of this module is so that if people were to make programs that require a LAN system, they can use what is provided here. <br>
This project is also named after my ~ windy ~ friend :3 <br>
The first section will explain instructions that apply to both, and then we will cover each individual part.

# **General setup**
Before we do anything, you should first install this module with pip. <br></br>
`pip install lynxy` <br>
`python3 -m pip install lynxy` <br> <br>
When you do this, it will install both the modules "lynxy" and "lynxy_server". Once this is done, you are ready to read the instructions on the following sections about setting up your client, server, or both.



# Server setup
To access server setup, go [**here**](./info/github/lynxy_server.md)

# Client setup
To access client setup, go [**here**](./info/github/lynxy.md)

# Etc
You can find more info about functions by looking at the descriptions of them in your code editor.
